BitBar Plugin — Meta Package Manager 2.4.0 documentation

# BitBar Plugin

A copy of the latest stable version of the BitBar plugin for `mpm` is always available on BitBar website and plugin repository.

## Development workflow

Active development of the plugin is happening here, as a side-project of `mpm` itself.

Releases of the plugin is synchronized with the package. Both share the exact same version to simplify management. This explain why the plugin could appears jumpimg ahead of a couple of major/minor version while providing tiny or no changes at all.

A release is ready when both the package and the plugin reach a stable state.

If the plugin has been changed between releases, a copy of the plugin is pushed to the official BitBar plugin repository.

## Release process

1. Fork the official BitBar plugin repository.

2. Fetch a local copy of the fork:

       $ git clone https://github.com/kdeldycke/bitbar-plugins
       $ cd bitbat-plugins

3. Create a new branch and switch to it:

       $ git branch meta-package-manager-v230
       $ git checkout meta-package-manager-v230

4. Replace existing copy of the plugin with the latest tagged version:

       $ wget https://raw.githubusercontent.com/kdeldycke/meta-package-manager/v2.3.0/meta_package_manager/bitbar/meta_package_manager.7h.py
       $ mv ./meta_package_manager.7h.py ./Dev/MetaPackageManager/
       $ chmod 755 ./Dev/MetaPackageManager/meta_package_manager.7h.py

5. Commit the new plugin:

       $ git add ./Dev/MetaPackageManager/meta_package_manager.7h.py
       $ git commit -m 'Upgrade to Meta Package Manager plugin v2.3.0.'

6. Push new branch:

       $ git push --set-upstream origin meta-package-manager-v230

7. Create a pull-request in the original repository.